-- zdepth swapper v1.2 April 2007
-- by ben cowell (http://www.rethinkfx.com) 

-- this script will alter the materials of selected objects,
-- a map will be added to the diffuse (max standard) or luminosity (brazil advanced)
-- this is an instanced fallof map to create a pseudo zdepth.

-- the following material parameters will be changed :

-- max standard : 
-- diffuse map amount =100
-- diffuse map =zdepth_map
-- self illumination amount =100
-- self illumination map =enabled
-- self illumination color =disabled
-- specularlevel =0
-- specularmap amount =0
-- reflection map will be turned off if 'remove reflections' is tagged

-- brazil advanced :
-- diffuse (Cs) color = black
-- diffuse (Cs) map =off
-- highlight shader amount =0
-- luminosity map = zdepth_map
-- luminosity map amount =100
-- reflection (Kr) amount will be turned to zero if 'remove reflections' is tagged
-- enviroment map will be turned off if 'remove reflections' is tagged

-- brazil basic :
-- diffuse (Cs) color = black
-- diffuse (Cs) map =off
-- xxxxxxxxx highlight shader amount =0
-- luminosity map = zdepth_map
-- luminosity map amount =100
-- xxxxxxxxx reflection (Kr) amount will be turned to zero if 'remove reflections' is tagged
-- enviroment map will be turned off if 'remove reflections' is tagged

-- currently only standard, blend, multisub, brazil basic, brazil advanced and brazil utility materials are supported
-- note : SAVE YOUR SCENE FIRST ! (it's unlikely you'll be able to undo)

function material_test current_material material_array_passed =
(
	result = false
	for j = 1 to material_array_passed.count do
	(
		if material_array_passed[j] != current_material then
		(
			result = false
		)
		else
		(
			result = true
			exit
		)
	)
	return result
)	
	
function process_scene kill_reflections =
(
	material_array = #()
	x=1

	if classof selection[1].material == Multimaterial then
	(
		for y=1 to selection[1].material.count do
		(
			material_array[x] = selection[1].material[y]
			x=x+1
		)
	)
	
	if classof selection[1].material == Brazil_Advanced then
	(
		material_array[1] = selection[1].material
		x=x+1
	)
	
	if classof selection[1].material == Standard then
	(
		material_array[1] = selection[1].material
		x=x+1
	)
	
	if classof selection[1].material == Blend then
	(
		material_array[1] = selection[1].material.map1
		material_array[2] = selection[1].material.map2
		x=3
	)

	if classof selection[1].material == Brazil_Utility then
	(
		material_array[1] = selection[1].sub_material
		x=x+1
	)
	
	if classof selection[1].material == Brazil_Basic_Mtl then
	(
		material_array[1] = selection[1].material
		x=x+1
	)
	
	for i = 2 to selection.count do
	(
		if classof selection[i].material == Multimaterial then
		(
			for y=1 to selection[i].material.count do
			(
				if material_test selection[i].material[y] material_array == false then 
				(
					material_array[x] = selection[i].material[y]
					x = x + 1
				)
			)
		)
		
		if classof selection[i].material == Standard then
		(
			if material_test selection[i].material material_array == false then 
			(
				material_array[x] = selection[i].material
				x=x+1
			)
		)
		
		if classof selection[i].material == Brazil_Advanced then
		(
			if material_test selection[i].material material_array == false then 
			(
				material_array[x] = selection[i].material
				x=x+1
			)
		)
		
		if classof selection[i].material == Blend then
		(
			if material_test selection[i].material.map1 material_array == false then 
			(
				material_array[x] = selection[i].material.map1
				x = x + 1
			)
			if material_test selection[i].material.map2 material_array == false then 
			(
				material_array[x] = selection[i].material.map2
				x = x + 1
			)
		)
		
		if classof selection[i].material == Brazil_Utility then
		(
			if material_test selection[i].material.sub_material material_array == false then 
			(
				material_array[x] = selection[i].material.sub_material
				x=x+1
			)
		)
		
		if classof selection[i].material == Brazil_Basic_Mtl then
		(
			if material_test selection[i].material material_array == false then 
			(
				material_array[x] = selection[i].material
				x=x+1
			)
		)
	)
	
	near_var = 0
	far_var = 700
	
	zdepth_map = falloff name:"zdepth_map" type:4 nearDistance:near_var farDistance:far_var

	for i = 1 to material_array.count do
	(
		if classof material_array[i] == Standard then
		(
			print "STANDARD"
			material_array[i].diffuseMapAmount = (100)
			material_array[i].selfIllumAmount = (100)
			material_array[i].selfIllumMapEnable = false
			material_array[i].useSelfIllumColor = false
			material_array[i].diffusemap = zdepth_map
			material_array[i].specularlevel =0
			material_array[i].specularLevelMapEnable = off
			if kill_reflections == true then material_array[i].reflectionMapEnable = off
		)
		
		if classof material_array[i] == Brazil_Advanced then
		(
			print "BRAZIL ADVANCED"
			material_array[i].bmtl_Cs_color = (color 0 0 0)
			material_array[i].bmtl_Cs_map_on = off
			material_array[i].bmtl_bcomp_amt = 0
			material_array[i].texmapMgr.luminosity.tms_map = zdepth_map
			material_array[i].texmapMgr.luminosity.tms_map_amt = 1
			if kill_reflections == true then material_array[i].brazildefault.Kr = 0
			if kill_reflections == true then material_array[i].bmtl_env_map_on = false
		)			
		if classof material_array[i] == Brazil_Basic_Mtl then
		(
			print "BRAZIL BASIC"
			messageBox "Brazil Basic Materials not supported."
			exit
		)
	)
)

rollout FirstRollout ""
(
	group ""
	(
		label label_01 "Z-depth Swapper v1.2"
		label label_02 "by Ben Cowell"
		hyperlink link_01 "http://www.rethinkfx.com" address:"http://www.rethinkfx.com" pos:[20,60]
	)
	group ""
	(
		label label_03 "remember to save"
		label label_04 "cannot undo"
		checkbox kill_reflections "Remove Reflections" pos:[24,160]
		button process_selected "Process Selected" pos:[32,190]

	)
	on process_selected pressed do
	(
		if $ != undefined then
		(
			process_scene(kill_reflections.checked)
		)
		else messagebox "Nothing selected" title:"Error"
	)
)

BC_zdepth_swapper_Dialog = newRolloutFloater "zdepth_Swapper v1.2" 180 270
addrollout FirstRollout BC_zdepth_swapper_Dialog


